
#include "mdBlinky.h"

// The constructor needs to known the pin connected to the LED
// and if it is active HIGH or LOW.
mdBlinky blinky(LED_BUILTIN, ACTIVE_HIGH);

#define DISPLAY_TIME 10000  // display time of each mode


// Testing various timing patterns
//
//                          blinks
//                          |    blinkofftime
//                          |    |    blinkontime
//                          |    |    |      offtime       
//                          |    |    |      |
uint16_t blink_params[] = { 2, 200,  30 , 1740,  // heartbeat
                            4, 100,  40,   540,  // disconnected
                            2,  50,  25,   350,  // reset
                            1,   0, 800,  2200,  // manual
                            1,   0, 100,   100,  // panic
                            0,   0,   0,     1,  // allways on
                            0,   0,   0,     0}; // allways off
                          

unsigned long timer;
int Index;

void setup() {
  Serial.begin(9600);
  delay(100);

  blinky.setMode(ON);
  Index = -2;  

  Serial.println("\n\nsetup() completed");
  printMode();
  timer = millis();
}

void loop() {

  blinky.blink(); // DON'T forget this
  
  if ( (millis() - timer) > DISPLAY_TIME ) {
    Index += 1;
    if (Index > 6) {
      Index = -2;
    } 
     if (Index == -2) {
      blinky.setMode(ON);
    } else if (Index == -1) {
      blinky.setMode(OFF);
    } else {
      blinky.setParams(blink_params, Index);
    }
    printMode();
    timer = millis();
  }
}

void printMode(void) {
  Serial.print("getMode=");
  switch (blinky.getMode()) {
    case OFF: Serial.println("OFF"); break;
    case ON: Serial.println("ON"); break;
    case BLINK: Serial.println("BLINK"); break;
  }
  switch(Index) {
    case 0: Serial.println("pattern: Heartbeat"); break;
    case 1: Serial.println("pattern: Disconnnected"); break;
    case 2: Serial.println("pattern: reset"); break;
    case 3: Serial.println("pattern: manual"); break;
    case 4: Serial.println("pattern: panic"); break;
    case 5: Serial.println("pattern: always on"); break;
    case 6: Serial.println("pattern: always off"); break;
  }  
  Serial.println();
}
